[systemd-commits] TODO man/journald.conf.xml src/journal

Lennart Poettering lennart at kemper.freedesktop.org
Tue Jul 10 10:40:37 PDT 2012


 TODO                   |    4 ++--
 man/journald.conf.xml  |    6 +++---
 src/journal/journald.c |   10 +++++-----
 src/journal/journald.h |    2 +-
 4 files changed, 11 insertions(+), 11 deletions(-)

New commits:
commit 205c4d1d6a3f5343f970abf20283d69dcec359ed
Author: Lennart Poettering <lennart at poettering.net>
Date:   Tue Jul 10 19:39:27 2012 +0200

    journald: use "persistent", not "permanent" as storage option
    
    "permanent" is simply the wrong term and we use "persistant" in most
    other contexts to correct this.

diff --git a/TODO b/TODO
index 8975ad0..09b34e5 100644
--- a/TODO
+++ b/TODO
@@ -34,6 +34,8 @@ Bugfixes:
 
 Features:
 
+* replace BindTo= by BindsTo=, but keep old name for compat
+
 * switch-root: sockets need relabelling
 
 * switch-root: handle journald restart
@@ -42,8 +44,6 @@ Features:
 
 * systemd-analyze post-boot is broken for initrd
 
-* journal: s/permanent/persistant
-
 * man: clarify that time-sync.target is not only sysv compat but also useful otherwise. Same for similar targets
 
 * journalctl should complain if run with uid != 0 and no persistant logs exist
diff --git a/man/journald.conf.xml b/man/journald.conf.xml
index f82130b..3622709 100644
--- a/man/journald.conf.xml
+++ b/man/journald.conf.xml
@@ -293,7 +293,7 @@
                                 <listitem><para>Controls where to
                                 store journal data. One of
                                 <literal>volatile</literal>,
-                                <literal>permanent</literal>,
+                                <literal>persistent</literal>,
                                 <literal>auto</literal> and
                                 <literal>none</literal>. If
                                 <literal>volatile</literal> journal
@@ -302,7 +302,7 @@
                                 <filename>/run/log/journal</filename>
                                 hierarchy (which is created if
                                 needed). If
-                                <literal>permanent</literal> data will
+                                <literal>persistent</literal> data will
                                 be stored preferably on disk,
                                 i.e. below the
                                 <filename>/var/log/journal</filename>
@@ -313,7 +313,7 @@
                                 early boot and if the disk is not
                                 writable. <literal>auto</literal> is
                                 similar to
-                                <literal>permanent</literal> but the
+                                <literal>persistent</literal> but the
                                 directory
                                 <filename>/var/log/journal</filename>
                                 is not created if needed, so that its
diff --git a/src/journal/journald.h b/src/journal/journald.h
index 34deb85..3537a49 100644
--- a/src/journal/journald.h
+++ b/src/journal/journald.h
@@ -36,7 +36,7 @@
 typedef enum Storage {
         STORAGE_AUTO,
         STORAGE_VOLATILE,
-        STORAGE_PERMANENT,
+        STORAGE_PERSISTENT,
         STORAGE_NONE,
         _STORAGE_MAX,
         _STORAGE_INVALID = -1



More information about the systemd-commits mailing list
diff --git a/src/journal/journald.c b/src/journal/journald.c
index 0629f79..da9f528 100644
--- a/src/journal/journald.c
+++ b/src/journal/journald.c
@@ -114,7 +114,7 @@ struct StdoutStream {
 static const char* const storage_table[] = {
         [STORAGE_AUTO] = "auto",
         [STORAGE_VOLATILE] = "volatile",
-        [STORAGE_PERMANENT] = "permanent",
+        [STORAGE_PERSISTENT] = "persistent",
         [STORAGE_NONE] = "none"
 };
 
@@ -1963,16 +1963,16 @@ static int system_journal_open(Server *s) {
         sd_id128_to_string(machine, ids);
 
         if (!s->system_journal &&
-            (s->storage == STORAGE_PERMANENT ||
+            (s->storage == STORAGE_PERSISTENT ||
              s->storage == STORAGE_AUTO)) {
 
                 /* If in auto mode: first try to create the machine
                  * path, but not the prefix.
                  *
                  * If in permanent mode: create /var/log/journal and
                  * the machine path */
 
-                if (s->storage & STORAGE_PERMANENT)
+                if (s->storage & STORAGE_PERSISTENT)
                         (void) mkdir("/var/log/journal/", 0755);
 
                 fn = strappend("/var/log/journal/", ids);
@@ -2067,7 +2067,7 @@ static int server_flush_to_var(Server *s) {
         assert(s);
 
         if (s->storage != STORAGE_AUTO &&
-            s->storage != STORAGE_PERMANENT)
+            s->storage != STORAGE_PERSISTENT)
                 return 0;
 
         if (!s->runtime_journal)
@@ -1963,16 +1963,16 @@ static int system_journal_open(Server *s) {
                  * path, but not the prefix.
                  *
-                 * If in permanent mode: create /var/log/journal and
+                 * If in persistent mode: create /var/log/journal and
                  * the machine path */
 